@@ -161,8 +161,8 @@ my $extract_perl_v
 
             $perl_v = $pass1->numify
         }
-        or 
-        die "Unparsable perl version: '$v'\n"
+        or
+        die "Unparsable \$^V: '$v', $@";
     }
     elsif( my $path = $extract->value( 'version_from' ) )
     {
@@ -238,13 +238,21 @@ DIE
     else
     {
         # this *should* always be parseable.
+        # but is isn't! 5.8 has problems with
+        # version dealing with $^V. Hopefully
+        # the eval will give a better idea of
+        # what is going on.
 
-        print "#  Running Perl: '$^V'"
+        print STDERR "#  Running Perl: '$^V'"
         if $verbose;
 
-        $perl_v = version->parse( $^V )->numify
+        $perl_v 
+        = eval
+        {
+            version->parse( $^V )->numify
+        }
         or
-        die "Severe weirdness: unparsable \$^V ($^V).\n";
+        die "Unparsable \$^V: '$^V', $@.\n";
     }
 
     # at this point the version has been parsed and numified.
@@ -260,7 +268,16 @@ my @handlerz =
         # acquire running perl version.
 
         my $extract = shift;
-        my $perl_v  = $extract->$extract_perl_v;
+        my $perl_v  
+        = eval
+        {
+            $extract->$extract_perl_v;
+        }
+        or do
+        {
+            print STDERR "Failed: Extract perl version, $@";
+            die
+        };
 
         # lacking an exception, we have a perl version.
 
@@ -335,7 +352,7 @@ my @handlerz =
 
         my ( $mod_v, $path ) = @$found;
 
-        print "# Module version: $mod_v <= $perl_v";
+        print "# Module selects: '$mod_v' from $perl_v";
 
         $extract->value( module_source => $path );
 
